@@ -376,7 +376,7 @@ class PointSet:
 
         return pointset
 
-    def to_local(self, inplace: bool = True) -> np.ndarray:
+    def to_local(self, inplace: bool = True) -> "PointSet":
         """Transform pointset to a local frame tangential to the
            (grs80) ellipsoid
 
@@ -387,7 +387,7 @@ class PointSet:
                                       Defaults to True.
 
         Returns:
-            np.ndarray: 2-dimensional array containing xyz of the
+            PointSet: 2-dimensional PointSet containing xyz of the
                         transformed points
         """
         return self.to_epsg(target_epsg=0, inplace=inplace)
